
#[derive(Hash, Clone, Default)]
pub struct Route {
    pub id:u32,
    pub name: String,
    pub short_name: String,
    pub color: String,
    pub poly_line: String,
    pub stops: Vec<crate::stop::Stop>,
    pub service: crate::types::Service
}
#[derive(serde::Deserialize)]
struct OcctRoute {
    id:u32,
    name: String,
    #[serde(rename(deserialize = "abbr"))]
    short_name: String,
    #[serde(rename(deserialize = "encLine"))]
    poly_line: String,
    stops:Vec<u32>,
    color: String
}
//impl From<OcctRoute> for Route{
//    fn from(OcctRoute{id,name,short_name,poly_line,stops, color}: OcctRoute) -> Self {
//        Self {
//            id,
//            name,
//            short_name,
//            color,
//            poly_line,
//            
//        }
//    }
//}
#[derive(serde::Deserialize)]
struct BCRoute{
    id:u32,
    name: String,
    short_name: String,
    color: String,
    path: Vec<f64>,
    active: bool,
    stops:Vec<u32>
}
#[derive(serde::Deserialize)]
struct OcctWrap{
    get_routes:Vec<OcctRoute>
}
pub async fn occt_routes_get()->anyhow::Result<Vec<Route>>{
    let resp = reqwest::get("http://binghamtonupublic.etaspot.net/service.php?service=get_routes&token=TESTING").await?;
    let body = resp.text().await?;
    let OcctWrap{get_routes: routes} = serde_json::from_str(body.as_str())?;
    let stops = crate::stop::occt_stops_get().await?;
    let routes = routes.into_iter().map(|route|{
        let stops = stops.iter()
            .filter(|stop|{
                route.stops.iter().any(|id|*id==stop.id)
            }).map(Clone::clone).collect();

        Route{
            id:route.id,
            color:route.color,
            name:route.name,
            poly_line:route.poly_line,
            short_name: route.short_name,
            stops,
            service: crate::types::Service::OCCT
        }
    }).collect();
    Ok(routes)

}
pub async fn broome_county_routes_get()->anyhow::Result<Vec<Route>>{
    let resp = reqwest::get("https://bctransit.doublemap.com/map/v2/routes").await?;
    let body = resp.text().await?;
    let routes:Vec<BCRoute> = serde_json::from_str(body.as_str())?;
    let stops = crate::stop::bc_stops_get().await?;
    let routes = routes.into_iter().map(|route|{
        let stops:Vec<crate::stop::Stop> = stops.iter()
            .filter(|stop|{
                route.stops.iter().any(|id|*id==stop.id)
            }).map(Clone::clone).collect();
        let poly_line = crate::stop::poly_encode_stops(stops.clone());
        Route{
            id:route.id,
            color:route.color,
            name:route.name,
            poly_line,
            short_name: route.short_name,
            stops,
            service: crate::types::Service::BC
        }
    }).collect();
    Ok(routes)
}
